AcsCallState enum

Call state values

Inheritance
Available extensions

Values

none → const AcsCallState

No call state

connecting → const AcsCallState

Connecting to the call

ringing → const AcsCallState

Call is ringing

connected → const AcsCallState

Connected to the call

localHold → const AcsCallState

Call is on hold locally

remoteHold → const AcsCallState

Call is on hold remotely

disconnecting → const AcsCallState

Disconnecting from the call

disconnected → const AcsCallState

Disconnected from the call

inLobby → const AcsCallState

In lobby waiting to be admitted

unknown → const AcsCallState

Unknown state

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AcsCallState>
A constant List of the values in this enum, in order of their declaration.