AudioOutput enum

In-call audio output destinations that can be selected at runtime.

Used by the dynamic audio-routing API on the calling client. The default while a call is active is auto, which keeps the built-in loudspeaker unless an external device (Bluetooth / wired / USB / hearing aid) is connected, in which case the external device is used. The other values force a specific destination until the app selects another value or returns to auto.

Inheritance
Available extensions

Values

auto → const AudioOutput

Automatic routing: built-in loudspeaker by default, external device when one is connected. This is the default in-call behaviour.

speaker → const AudioOutput

The built-in loudspeaker (hands-free).

earpiece → const AudioOutput

The phone's earpiece / receiver (held-to-ear).

bluetooth → const AudioOutput

A connected Bluetooth audio device.

wiredHeadset → const AudioOutput

A connected wired headset / headphones.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AudioOutput>
A constant List of the values in this enum, in order of their declaration.