Call class

Represents an active call

Constructors

Call({required String id, required CallState state})
Creates a new Call instance
const
Call.fromMap(Map<String, dynamic> map)
Creates a Call from a map
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier for the call
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state CallState
The current state of the call
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Converts this Call to a map
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited