DiagnosticsEvent class
Event emitted when diagnostics change.
Contains information about call quality issues including:
- Network diagnostics (connection, bandwidth)
- Media diagnostics (audio/video device issues)
- User facing diagnostics (muted while speaking, etc.)
Constructors
-
DiagnosticsEvent({required String type, required Map<
String, dynamic> data}) -
const
-
DiagnosticsEvent.fromMap(Map<
String, dynamic> map) -
factory
Properties
-
data
→ Map<
String, dynamic> -
Raw event data for backward compatibility
final
- diagnostic → String?
-
The specific diagnostic that changed (e.g., 'networkUnavailable')
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFlagDiagnostic → bool
-
Whether this is a flag-type diagnostic (true/false)
no setter
-
mediaDiagnostics
→ Map<
String, dynamic> ? -
Media diagnostics snapshot
no setter
-
networkDiagnostics
→ Map<
String, dynamic> ? -
Network diagnostics snapshot
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The event type identifier
final
- valueBool → bool?
-
The diagnostic value - can be bool for flag diagnostics
no setter
- valueQuality → String?
-
The diagnostic value as a quality enum string (e.g., 'good', 'poor', 'bad')
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited